<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <location filename="../src/alert.cpp" line="236"/>
        <source>Close (%1)</source>
        <translation>关闭 (%1)</translation>
    </message>
    <message>
        <location filename="../src/alert.cpp" line="177"/>
        <source>Collapse</source>
        <translation>折叠</translation>
    </message>
    <message>
        <location filename="../src/alert.cpp" line="181"/>
        <source>Expand</source>
        <translation>展开</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <location filename="../src/alert_layer.cpp" line="37"/>
        <source>Dismiss Alert</source>
        <translation>忽略警告</translation>
    </message>
    <message>
        <location filename="../src/alert_layer.cpp" line="38"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <location filename="../src/document.cpp" line="358"/>
        <location filename="../src/document.cpp" line="383"/>
        <location filename="../src/document.cpp" line="414"/>
        <location filename="../src/document.cpp" line="420"/>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="358"/>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>不能保存 &apos;%1&apos;。</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="373"/>
        <source>Save File As</source>
        <translation>保存文件为</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="383"/>
        <location filename="../src/document.cpp" line="414"/>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>不能覆盖 &apos;%1&apos;。</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="407"/>
        <source>Rename File</source>
        <translation>重命名文件</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="420"/>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>不能重命名 &apos;%1&apos;。</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="445"/>
        <source>Reload File</source>
        <translation>重新加载文件</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="446"/>
        <source>Reload the file %1 from disk?</source>
        <translation>重新从磁盘中加载文件 %1 ？</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="447"/>
        <source>All unsaved changes will be lost.</source>
        <translation>未保存的更改将丢失。</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="449"/>
        <source>Reload</source>
        <translation>重新加载</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1198"/>
        <source>Plain Text (*.txt)</source>
        <translation>纯文本 (*.txt)</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1257"/>
        <source>Question</source>
        <translation>问题</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1258"/>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>保存为纯文本将丢弃全部格式。丢弃格式吗？</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1196"/>
        <source>OpenDocument Text (*.odt)</source>
        <translation>OpenDocument Text (*.odt)</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1197"/>
        <source>Rich Text (*.rtf)</source>
        <translation>多信息文本格式 (*.rtf)</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1199"/>
        <source>All Files (*)</source>
        <translation>所有文件 (*)</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <location filename="../src/document_watcher.cpp" line="189"/>
        <source>File Changed</source>
        <translation>文件已更改</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="190"/>
        <source>The file %1 was changed by another program.</source>
        <translation>文件 %1 已由其他程序更改。</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="191"/>
        <source>Do you want to reload the file?</source>
        <translation>您要重新加载文件吗？</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="193"/>
        <source>Reload</source>
        <translation>重新加载</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="198"/>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="209"/>
        <source>File Deleted</source>
        <translation>文件已删除</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="210"/>
        <source>The file %1 was deleted by another program.</source>
        <translation>文件 %1 已经由其他程序删除。</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="211"/>
        <source>Do you want to save or close the file?</source>
        <translation>您要保存或关闭该文件？</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <location filename="../src/find_dialog.cpp" line="45"/>
        <source>Search for:</source>
        <translation>搜索：</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="47"/>
        <source>Replace with:</source>
        <translation>替换为：</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="51"/>
        <source>Ignore case</source>
        <translation>忽略大小写</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="52"/>
        <source>Whole words only</source>
        <translation>全字匹配</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="53"/>
        <source>Regular expressions</source>
        <translation>正则表达式</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="56"/>
        <source>Search up</source>
        <translation>向上搜索</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="57"/>
        <source>Search down</source>
        <translation>向下搜索</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="64"/>
        <source>&amp;Find</source>
        <translation>查找(&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="68"/>
        <source>&amp;Replace</source>
        <translation>替换(&amp;R)</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="72"/>
        <source>Replace &amp;All</source>
        <translation>替换全部(&amp;A)</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="134"/>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="142"/>
        <source>Replace</source>
        <translation>替换</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/find_dialog.cpp" line="258"/>
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>替换 %n 个实例？</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="258"/>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="262"/>
        <location filename="../src/find_dialog.cpp" line="337"/>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="262"/>
        <location filename="../src/find_dialog.cpp" line="337"/>
        <source>Phrase not found.</source>
        <translation>没找到词组。</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <location filename="../src/highlighter.cpp" line="52"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../src/highlighter.cpp" line="53"/>
        <source>Check Spelling...</source>
        <translation>检查拼写...</translation>
    </message>
    <message>
        <location filename="../src/highlighter.cpp" line="127"/>
        <source>(No suggestions found)</source>
        <translation>（找不到建议）</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <location filename="../src/image_button.cpp" line="90"/>
        <source>Open Image</source>
        <translation>打开图像</translation>
    </message>
    <message>
        <location filename="../src/image_button.cpp" line="90"/>
        <source>Images(%1)</source>
        <translation>图像(%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>选择程序语言：</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;系统语言&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>注意</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>要使语言的变化生效，请重新启动该应用程序。</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="109"/>
        <source>Preferences</source>
        <translation>首选项</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="112"/>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="113"/>
        <source>Statistics</source>
        <translation>统计</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="115"/>
        <source>Toolbar</source>
        <translation>工具栏</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="114"/>
        <source>Spell Checking</source>
        <translation>拼写检查</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="406"/>
        <source>Select Dictionary</source>
        <translation>选择词典</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="420"/>
        <location filename="../src/preferences_dialog.cpp" line="541"/>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="420"/>
        <source>Unable to open archive.</source>
        <translation>不能打开存档。</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="428"/>
        <source>Unable to read archive metadata.</source>
        <translation>无法读取存档元数据。</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="470"/>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>存档不包含可用的词典。</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="496"/>
        <source>Unable to open file &apos;%1&apos;.</source>
        <translation>不能打开文件 &apos;%1&apos;。</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="507"/>
        <source>Unable to close file &apos;%1&apos;.</source>
        <translation>不能关闭文件 &apos;%1&apos;。</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="243"/>
        <location filename="../src/preferences_dialog.cpp" line="527"/>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="116"/>
        <source>Shortcuts</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="244"/>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>一个或多个快捷键冲突。您要继续吗？</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="527"/>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>词典 &quot;%1&quot; 已经存在。您要替换它吗？</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="676"/>
        <source>Daily Goal</source>
        <translation>每日目标</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="678"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="680"/>
        <source>Minutes:</source>
        <translation>分钟：</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="692"/>
        <location filename="../src/preferences_dialog.cpp" line="819"/>
        <source>Words:</source>
        <translation>字数：</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="710"/>
        <source>Editing</source>
        <translation>编辑</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="712"/>
        <source>Always vertically center</source>
        <translation>始终垂直居中</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="713"/>
        <source>Block insertion cursor</source>
        <translation>块状光标</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="714"/>
        <source>Smooth fonts</source>
        <translation>平滑字体</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="715"/>
        <source>Typewriter sounds</source>
        <translation>打字机声音</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="717"/>
        <source>Smart quotes:</source>
        <translation>智能引号：</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="724"/>
        <source>Double</source>
        <translation>双倍行距</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="725"/>
        <source>Single</source>
        <translation>单线</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="746"/>
        <source>Scenes</source>
        <translation>场景</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="753"/>
        <source>Divider:</source>
        <translation>分隔符:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="756"/>
        <source>Saving</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="758"/>
        <source>Automatically save changes</source>
        <translation>自动保存更改</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="759"/>
        <source>Remember cursor position</source>
        <translation>记住光标位置</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="783"/>
        <source>Contents</source>
        <translation>内容</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="785"/>
        <source>Word count</source>
        <translation>字数</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="786"/>
        <source>Page count</source>
        <translation>页数</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="787"/>
        <source>Paragraph count</source>
        <translation>段落数</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="788"/>
        <source>Character count</source>
        <translation>字符数</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="797"/>
        <source>Page Size</source>
        <translation>页面大小</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="799"/>
        <source>Characters:</source>
        <translation>字符：</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="809"/>
        <source>Paragraphs:</source>
        <translation>段落：</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="835"/>
        <source>Word Count Algorithm</source>
        <translation>字数统计规则</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="837"/>
        <source>Detect word boundaries</source>
        <translation>探测单词边界</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="838"/>
        <source>Divide character count by six</source>
        <translation>字符数除以6</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="943"/>
        <source>Style</source>
        <translation>样式</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="946"/>
        <source>Icons Only</source>
        <translation>仅图标</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="947"/>
        <source>Text Only</source>
        <translation>仅文本</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="948"/>
        <source>Text Alongside Icons</source>
        <translation>文本在图标旁</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="949"/>
        <source>Text Under Icons</source>
        <translation>文本在图标下</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="953"/>
        <source>Text Position:</source>
        <translation>文本位置：</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="956"/>
        <source>Actions</source>
        <translation>动作</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="972"/>
        <source>Move Up</source>
        <translation>上移</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="974"/>
        <source>Move Down</source>
        <translation>下移</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="976"/>
        <source>Add Separator</source>
        <translation>添加分隔符</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1010"/>
        <source>Command</source>
        <translation>命令</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1010"/>
        <source>Shortcut</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1010"/>
        <source>Action</source>
        <translation>动作</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="863"/>
        <source>Check spelling as you type</source>
        <translation>输入时检查拼写</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="864"/>
        <source>Ignore words in UPPERCASE</source>
        <translation>忽略大写单词</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="865"/>
        <source>Ignore words with numbers</source>
        <translation>忽略带数字的单词</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="878"/>
        <source>Language</source>
        <translation>语言</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="882"/>
        <location filename="../src/preferences_dialog.cpp" line="903"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="915"/>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="898"/>
        <source>Personal Dictionary</source>
        <translation>个人词典</translation>
    </message>
</context>
<context>
    <name>Reader</name>
    <message>
        <location filename="../src/rtf/reader.cpp" line="226"/>
        <location filename="../src/rtf/reader.cpp" line="230"/>
        <source>Not a supported RTF file.</source>
        <translation>不支持的RTF文件。</translation>
    </message>
    <message>
        <location filename="../src/odt_reader.cpp" line="64"/>
        <source>Unable to open archive.</source>
        <translation>不能打开存档。</translation>
    </message>
    <message>
        <location filename="../src/odt_reader.cpp" line="78"/>
        <source>Unable to open file &apos;%1&apos;.</source>
        <translation>不能打开文件 &apos;%1&apos;。</translation>
    </message>
    <message>
        <location filename="../src/odt_reader.cpp" line="89"/>
        <source>Unable to close file &apos;%1&apos;.</source>
        <translation>不能关闭文件 &apos;%1&apos;。</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <location filename="../src/scene_list.cpp" line="89"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="94"/>
        <source>Move Scenes Up</source>
        <translation>向上移动场景</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="95"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="115"/>
        <source>Toggle Scene List</source>
        <translation>打开/关闭场景列表</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="116"/>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="399"/>
        <source>Show scene list (%1)</source>
        <translation>显示场景列表(%1)</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="400"/>
        <source>Hide scene list (%1)</source>
        <translation>隐藏场景列表(%1)</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="147"/>
        <source>Filter</source>
        <translation>过滤器</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="88"/>
        <source>Move Scenes Down</source>
        <translation>向下移动场景</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="155"/>
        <source>Resize scene list</source>
        <translation>调整场景列表大小</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../src/main.cpp" line="173"/>
        <location filename="../src/session.cpp" line="35"/>
        <location filename="../src/session.cpp" line="42"/>
        <location filename="../src/session_manager.cpp" line="148"/>
        <location filename="../src/session_manager.cpp" line="360"/>
        <location filename="../src/session_manager.cpp" line="377"/>
        <location filename="../src/session_manager.cpp" line="380"/>
        <location filename="../src/theme_manager.cpp" line="193"/>
        <source>Default</source>
        <translation>默认</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <location filename="../src/session_manager.cpp" line="47"/>
        <source>Manage Sessions</source>
        <translation>管理会话</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="51"/>
        <source>S&amp;essions</source>
        <translation>会话(&amp;E)</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="64"/>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="67"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="70"/>
        <source>Clone</source>
        <translation>克隆</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="73"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="76"/>
        <source>Switch To</source>
        <translation>切换到</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="171"/>
        <source>New Session</source>
        <translation>新会话</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="217"/>
        <source>Clone Session</source>
        <translation>克隆会话</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="257"/>
        <source>Rename Session</source>
        <translation>重命名会话</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="284"/>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="284"/>
        <source>Delete selected session?</source>
        <translation>删除所选会话？</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="355"/>
        <source>Session name:</source>
        <translation>会话名称：</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="363"/>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="363"/>
        <source>The requested session name is already in use.</source>
        <translation>请求的会话名称已在使用中。</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="403"/>
        <source>&amp;New...</source>
        <translation>新建(&amp;N)...</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="403"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="404"/>
        <source>&amp;Manage...</source>
        <translation>管理(&amp;M)...</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="404"/>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/shortcut_edit.cpp" line="36"/>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <location filename="../src/shortcut_edit.cpp" line="39"/>
        <source>Reset to Default</source>
        <translation>恢复默认</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1053"/>
        <location filename="../src/symbols_dialog.cpp" line="219"/>
        <source>Shortcut:</source>
        <translation>快捷键：</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <location filename="../src/smart_quotes.cpp" line="116"/>
        <source>Replacing quotation marks...</source>
        <translation>更换引号...</translation>
    </message>
    <message>
        <location filename="../src/smart_quotes.cpp" line="117"/>
        <source>Please Wait</source>
        <translation>请等待</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <location filename="../src/spell_checker.cpp" line="130"/>
        <source>Check Spelling</source>
        <translation>检查拼写</translation>
    </message>
    <message>
        <location filename="../src/spell_checker.cpp" line="138"/>
        <source>&amp;Add</source>
        <translation>添加(&amp;A)</translation>
    </message>
    <message>
        <location filename="../src/spell_checker.cpp" line="141"/>
        <source>&amp;Ignore</source>
        <translation>忽略(&amp;I)</translation>
    </message>
    <message>
        <location filename="../src/spell_checker.cpp" line="144"/>
        <source>I&amp;gnore All</source>
        <translation>忽略全部(&amp;g)</translation>
    </message>
    <message>
        <location filename="../src/spell_checker.cpp" line="149"/>
        <source>&amp;Change</source>
        <translation>更改(&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/spell_checker.cpp" line="152"/>
        <source>C&amp;hange All</source>
        <translation>更改全部(&amp;h)</translation>
    </message>
    <message>
        <location filename="../src/spell_checker.cpp" line="167"/>
        <source>Not in dictionary:</source>
        <translation>不在词典中：</translation>
    </message>
    <message>
        <location filename="../src/spell_checker.cpp" line="175"/>
        <source>Change to:</source>
        <translation>更改为：</translation>
    </message>
    <message>
        <location filename="../src/spell_checker.cpp" line="190"/>
        <source>Checking spelling...</source>
        <translation>检查拼写...</translation>
    </message>
    <message>
        <location filename="../src/spell_checker.cpp" line="190"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/spell_checker.cpp" line="191"/>
        <source>Please wait</source>
        <translation>请等待</translation>
    </message>
    <message>
        <location filename="../src/spell_checker.cpp" line="258"/>
        <source>Spell check complete.</source>
        <translation>拼写检查完成。</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="96"/>
        <source>Symbols</source>
        <translation>符号</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="103"/>
        <source>Recently used symbols</source>
        <translation>最近使用过的符号</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="133"/>
        <source>All symbols</source>
        <translation>全部符号</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="195"/>
        <source>Details</source>
        <translation>详情</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="221"/>
        <source>Name:</source>
        <translation>名称：</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="231"/>
        <source>Insert</source>
        <translation>插入</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <location filename="../src/symbols_model.cpp" line="107"/>
        <source>Blocks</source>
        <translation>块</translation>
    </message>
    <message>
        <location filename="../src/symbols_model.cpp" line="107"/>
        <source>Scripts</source>
        <translation>文字</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <location filename="../src/theme.cpp" line="104"/>
        <source>Untitled %1</source>
        <translation>无标题 %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <location filename="../src/theme_dialog.cpp" line="50"/>
        <source>Modify Theme</source>
        <translation>修改主题</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="60"/>
        <source>Name:</source>
        <translation>名称：</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="68"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="71"/>
        <source>No Image</source>
        <translation>无图像</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="71"/>
        <source>Tiled</source>
        <translation>平铺</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="71"/>
        <location filename="../src/theme_dialog.cpp" line="123"/>
        <source>Centered</source>
        <translation>居中</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="71"/>
        <location filename="../src/theme_dialog.cpp" line="123"/>
        <source>Stretched</source>
        <translation>拉伸</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="71"/>
        <source>Scaled</source>
        <translation>比例</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="71"/>
        <source>Zoomed</source>
        <translation>缩放</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="83"/>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="95"/>
        <source>Type:</source>
        <translation>类型：</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="96"/>
        <location filename="../src/theme_dialog.cpp" line="161"/>
        <location filename="../src/theme_dialog.cpp" line="200"/>
        <source>Color:</source>
        <translation>颜色：</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="97"/>
        <source>Image:</source>
        <translation>图像：</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="102"/>
        <source>Foreground</source>
        <translation>前景</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="113"/>
        <source>Opacity</source>
        <translation>不透明度</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="118"/>
        <location filename="../src/theme_dialog.cpp" line="129"/>
        <location filename="../src/theme_dialog.cpp" line="136"/>
        <location filename="../src/theme_dialog.cpp" line="142"/>
        <source> pixels</source>
        <translation>像素</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="123"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="123"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="125"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="162"/>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="163"/>
        <source>Rounding:</source>
        <translation>圆化：</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Margin:</source>
        <translation>页边距：</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="165"/>
        <source>Padding:</source>
        <translation>填充：</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="170"/>
        <source>Text</source>
        <translation>文本</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="201"/>
        <source>Font:</source>
        <translation>字体：</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="202"/>
        <source>Misspelled:</source>
        <translation>拼写错误：</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="207"/>
        <source>Spacings</source>
        <translation>间隔</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="209"/>
        <source>Line Spacing</source>
        <translation>行距</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="213"/>
        <source>Single</source>
        <translation>单线</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="213"/>
        <source>1.5 Lines</source>
        <translation>1.5 倍行距</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="213"/>
        <source>Double</source>
        <translation>双倍行距</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="213"/>
        <source>Proportional</source>
        <translation>成比例</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="232"/>
        <source>Paragraph Spacing</source>
        <translation>段间距</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="254"/>
        <source>Indent First Line:</source>
        <translation>首行缩进:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="255"/>
        <source>Pixels Above:</source>
        <translation>段前像素数:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="256"/>
        <source>Pixels Below:</source>
        <translation>段后像素数:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="492"/>
        <source>The quick brown fox jumps over the lazy dog</source>
        <translation>The quick brown fox jumps over the lazy dog</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <location filename="../src/theme_manager.cpp" line="47"/>
        <source>Themes</source>
        <translation>主题</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="73"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="77"/>
        <source>Modify</source>
        <translation>修改</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="81"/>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="85"/>
        <source>Import</source>
        <translation>导入</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="89"/>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="93"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="184"/>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="184"/>
        <source>Remove selected theme?</source>
        <translation>移除所选主题？</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="205"/>
        <source>Import Theme</source>
        <translation>导入主题</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="205"/>
        <source>Themes (*.fwtz *.theme)</source>
        <translation>主题 (*.fwtz *.theme)</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="266"/>
        <source>Themes (*.fwtz)</source>
        <translation>主题 (*.fwtz)</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="214"/>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="214"/>
        <source>A theme already exists with that name. Please enter a new name:</source>
        <translation>已经存在同名的一个主题。请输入新的名称：</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="266"/>
        <source>Export Theme</source>
        <translation>导出主题</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <location filename="../src/timer.cpp" line="255"/>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="340"/>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="340"/>
        <source>Delete timer?</source>
        <translation>删除定时器？</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="355"/>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;单词数：&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="356"/>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;页数：&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="357"/>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;段落数：&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="358"/>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;字符数：&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="402"/>
        <source>Set Delay</source>
        <translation>设定延迟</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="403"/>
        <source>Set Time</source>
        <translation>设定时间</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="406"/>
        <source>Delay:</source>
        <translation>延迟：</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="409"/>
        <source>Time:</source>
        <translation>时间：</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="418"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="431"/>
        <source>Alarm</source>
        <translation>闹铃</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="444"/>
        <source>Type:</source>
        <translation>类型：</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="448"/>
        <source>Memo:</source>
        <translation>备忘录：</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="459"/>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="461"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <location filename="../src/timer_display.cpp" line="150"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer_display.cpp" line="160"/>
        <source>No timers running</source>
        <translation>无定时器运行</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <location filename="../src/timer_manager.cpp" line="46"/>
        <source>Timers</source>
        <translation>定时器</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="78"/>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="83"/>
        <source>Recent</source>
        <translation>最近的</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="123"/>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="123"/>
        <source>Cancel editing timers?</source>
        <translation>取消编辑定时器吗？</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="316"/>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="323"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Tokenizer</name>
    <message>
        <location filename="../src/rtf/tokenizer.cpp" line="151"/>
        <source>Unexpectedly reached end of file.</source>
        <translation>意外地跳到了文件末尾.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="289"/>
        <source>Loading themes</source>
        <translation>载入主题</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1166"/>
        <source>Loading sounds</source>
        <translation>载入声音</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="295"/>
        <location filename="../src/window.cpp" line="1105"/>
        <source>Untitled</source>
        <translation>无标题</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="697"/>
        <source>Open File</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="888"/>
        <source>About FocusWriter</source>
        <translation>关于 FocusWriter</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="891"/>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="892"/>
        <source>A simple fullscreen word processor</source>
        <translation>一个简洁的全屏文字处理软件</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="893"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>版权 &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="894"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>以 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 许可协议发布</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="895"/>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>使用 &lt;a href=%1&gt;Oxygen&lt;/a&gt; 图标主题</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="896"/>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>遵照 &lt;a href=%1&gt;LGPL 3&lt;/a&gt; 许可使用</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="164"/>
        <location filename="../src/window.cpp" line="951"/>
        <source>Characters: %L1 / %L2</source>
        <translation>字符数：%L1 / %L2</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="162"/>
        <location filename="../src/window.cpp" line="952"/>
        <source>Pages: %L1</source>
        <translation>页数：%L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="163"/>
        <location filename="../src/window.cpp" line="953"/>
        <source>Paragraphs: %L1</source>
        <translation>段落数：%L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="161"/>
        <location filename="../src/window.cpp" line="954"/>
        <source>Words: %L1</source>
        <translation>单词数：%L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <location filename="../src/window.cpp" line="1016"/>
        <source>%1% of daily goal</source>
        <translation>每日目标的 %1%</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="462"/>
        <location filename="../src/window.cpp" line="1056"/>
        <source>Opening %1</source>
        <translation>正在打开 %1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1147"/>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1147"/>
        <source>Save changes?</source>
        <translation>保存更改？</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="353"/>
        <location filename="../src/window.cpp" line="1262"/>
        <source>(Untitled %1)</source>
        <translation>(无标题 %1)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="191"/>
        <source>Switch to Next Document</source>
        <translation>跳转到下一文档</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="197"/>
        <source>Switch to Previous Document</source>
        <translation>跳转到上一文档</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="203"/>
        <source>Switch to First Document</source>
        <translation>跳转到第一个文档</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="209"/>
        <source>Switch to Last Document</source>
        <translation>跳转到最后一个文档</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="217"/>
        <source>Switch to Document %1</source>
        <translation>跳转到文档 %1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="284"/>
        <source>Loading settings</source>
        <translation>加载设置中</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="303"/>
        <source>Emergency cache is not writable.</source>
        <translation>紧急缓存是不可写的。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="359"/>
        <location filename="../src/window.cpp" line="1070"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="360"/>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter 没有完全关闭。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="361"/>
        <source>Restore from the emergency cache?</source>
        <translation>从紧急缓存中还原？</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="495"/>
        <source>Some files could not be opened.</source>
        <translation>有些文件无法打开。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="498"/>
        <source>Some files were opened Read-Only.</source>
        <translation>一些文件以只读方式打开。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="697"/>
        <source>Text Files (%1);;All Files (*)</source>
        <translation>文本文件 (%1);;所有文件 (*)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1071"/>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; 比缓存的副本新。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1072"/>
        <source>Overwrite newer file?</source>
        <translation>覆盖较新的文件？</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1173"/>
        <source>Unable to load typewriter sounds.</source>
        <translation>无法加载打字机声音。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1174"/>
        <source>Please make sure that SDL_mixer is installed.</source>
        <translation>请确认 SDL_mixer 已被安装.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1265"/>
        <source>%1 (Read-Only)</source>
        <translation>%1 (只读)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1312"/>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1313"/>
        <source>&amp;New</source>
        <translation>新建(&amp;N)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1314"/>
        <source>&amp;Open...</source>
        <translation>打开(&amp;O)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1315"/>
        <source>Reloa&amp;d</source>
        <translation>重新载入(&amp;d)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1317"/>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1319"/>
        <source>Save &amp;As...</source>
        <translation>另存为(&amp;A)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1320"/>
        <source>&amp;Rename...</source>
        <translation>重命名(&amp;R)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1322"/>
        <source>Save A&amp;ll</source>
        <translation>全部保存(&amp;L)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1325"/>
        <source>Manage Sessions</source>
        <translation>管理会话</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1327"/>
        <source>New Session</source>
        <translation>新会话</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1330"/>
        <source>&amp;Print...</source>
        <translation>打印(&amp;P)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1332"/>
        <source>&amp;Close</source>
        <translation>关闭(&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1333"/>
        <source>&amp;Quit</source>
        <translation>退出(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1333"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1337"/>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1338"/>
        <source>&amp;Undo</source>
        <translation>撤销(&amp;U)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1341"/>
        <source>&amp;Redo</source>
        <translation>重做(&amp;R)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1345"/>
        <source>Cu&amp;t</source>
        <translation>剪切(&amp;T)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1348"/>
        <source>&amp;Copy</source>
        <translation>复制(&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1351"/>
        <source>&amp;Paste</source>
        <translation>粘贴(&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1352"/>
        <source>Paste &amp;Unformatted</source>
        <translation>无格式粘贴(&amp;U)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1352"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1354"/>
        <source>Select &amp;All</source>
        <translation>全选(&amp;A)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1355"/>
        <source>Select &amp;Scene</source>
        <translation>选择场景(&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1355"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1358"/>
        <source>Fo&amp;rmat</source>
        <translation>格式(&amp;R)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1360"/>
        <source>&amp;Bold</source>
        <translation>粗体(&amp;B)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1362"/>
        <source>&amp;Italic</source>
        <translation>斜体(&amp;I)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1364"/>
        <source>&amp;Underline</source>
        <translation>下划线(&amp;U)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1366"/>
        <source>Stri&amp;kethrough</source>
        <translation>删除线(&amp;K)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1366"/>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1368"/>
        <source>Sup&amp;erscript</source>
        <translation>上标(&amp;E)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1368"/>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1370"/>
        <source>&amp;Subscript</source>
        <translation>下标(&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1370"/>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1374"/>
        <source>Align &amp;Left</source>
        <translation>左对齐(&amp;L)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1374"/>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1376"/>
        <source>Align &amp;Center</source>
        <translation>居中(&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1376"/>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1378"/>
        <source>Align &amp;Right</source>
        <translation>右对齐(&amp;R)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1378"/>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1380"/>
        <source>Align &amp;Justify</source>
        <translation>两端对齐(&amp;J)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1380"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1390"/>
        <source>&amp;Decrease Indent</source>
        <translation>减少缩进(&amp;D)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1390"/>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1391"/>
        <source>I&amp;ncrease Indent</source>
        <translation>增加缩进(&amp;N)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1391"/>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1394"/>
        <source>Le&amp;ft to Right Block</source>
        <translation>从左到右(&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1396"/>
        <source>Ri&amp;ght to Left Block</source>
        <translation>从右到左 (&amp;G)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1404"/>
        <source>&amp;Tools</source>
        <translation>工具(&amp;T)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1405"/>
        <source>&amp;Find...</source>
        <translation>查找(&amp;F)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1406"/>
        <source>Find &amp;Next</source>
        <translation>查找下一个(&amp;N)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1409"/>
        <source>Find Pre&amp;vious</source>
        <translation>查找上一个(&amp;V)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1412"/>
        <source>&amp;Replace...</source>
        <translation>替换(&amp;R)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1412"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1414"/>
        <source>Smart &amp;Quotes</source>
        <translation>智能引号(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1415"/>
        <source>Update &amp;Document</source>
        <translation>更新文档(&amp;D)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1418"/>
        <source>Update &amp;Selection</source>
        <translation>更新所选(&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1422"/>
        <source>&amp;Spelling...</source>
        <translation>拼写(&amp;S)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1422"/>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1423"/>
        <source>&amp;Timers...</source>
        <translation>定时器(&amp;T)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1424"/>
        <source>S&amp;ymbols...</source>
        <translation>符号...(&amp;y)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1427"/>
        <source>&amp;Settings</source>
        <translation>设置(&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1428"/>
        <source>Show &amp;Toolbar</source>
        <translation>显示工具栏(&amp;T)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1433"/>
        <source>Show &amp;Menu Icons</source>
        <translation>显示菜单图标(&amp;M)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1439"/>
        <source>F&amp;ocused Text</source>
        <translation>聚焦文本(&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1441"/>
        <source>&amp;Fullscreen</source>
        <translation>全屏(&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1441"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1443"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1447"/>
        <source>M&amp;inimize</source>
        <translation>最小化(&amp;I)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1447"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1449"/>
        <source>&amp;Themes...</source>
        <translation>主题(&amp;T)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1452"/>
        <source>&amp;Preferences...</source>
        <translation>偏好设置(&amp;P)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1458"/>
        <source>Focus Off</source>
        <translation>关闭聚焦</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1460"/>
        <source>Focus One Line</source>
        <translation>聚焦一行</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1462"/>
        <source>Focus Three Lines</source>
        <translation>聚焦三行</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1463"/>
        <source>&amp;Paragraph</source>
        <translation>段落(&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1464"/>
        <source>Focus Paragraph</source>
        <translation>聚焦段落</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1477"/>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1451"/>
        <source>Application &amp;Language...</source>
        <translation>程序语言(&amp;L)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="427"/>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>某些文件不受支持，不能打开。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1457"/>
        <source>&amp;Off</source>
        <translation>关闭(&amp;O)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1459"/>
        <source>One &amp;Line</source>
        <translation>单行(&amp;L)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1461"/>
        <source>&amp;Three Lines</source>
        <translation>三行(&amp;T)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1478"/>
        <source>&amp;About</source>
        <translation>关于(&amp;A)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1486"/>
        <source>About &amp;Qt</source>
        <translation>关于 &amp;Qt</translation>
    </message>
</context>
</TS>
